%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: kvhvsrdi.m,v 1.1 2000/01/10 19:08:01 rob Exp $	

if exist( 'm_rdi_h' ) ~= 1
    warning( 'RDI SA variables not available' )
end

set( gcf, 'Name', 'DVL vs. AUV Attitude', 'defaultAxesFontSize', 16 )

ind = find(finite(data(:,m_rdi_h)));

subplot( 2, 1, 1 )
plot( data(ind,m_present_time), 180/pi*data(ind,[m_yaw m_rdi_h]) )
ylabel( 'heading (deg)' )


subplot( 4, 1, 3 )
plot( data(ind,m_present_time), 180/pi*data(ind,[m_pitch m_rdi_p]) )
ylabel( 'pitch (deg)' )


subplot( 4, 1, 4 )
plot( data(ind,m_present_time), 180/pi*data(ind,[m_roll m_rdi_r]) )
ylabel( 'roll (deg)' )

xlabel( 'elapsed time (s)' )
