%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: rev.m,v 1.1 2000/01/10 19:08:29 rob Exp $	

function rev( scale )

if nargin < 1, scale = 0.75; end

obj = findobj( get(gcf,'Children'), 'flat', 'Type', 'axes');

if ~isempty(obj)
    xlim = get( obj(1), 'XLim' );
    xwin( xlim - scale * diff(xlim) );
end
