% ROLLPLOT - Plot the roll angle in the current axes
%
%    B. A. Moran, 16-Jun-1995

%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: rollplot.m,v 1.1 2000/01/10 19:08:31 rob Exp $	

plot( data(:,m_present_time), data(:,m_roll)*180/pi );
xlabel( 'elapsed time (s)' );
ylabel( 'starboard roll (^{o})' );
zoom on
