%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% PURPOSE: Overlay real-time nav and lbl-filter data with post-processed,
%          stand-alone data.  
% AUTHOR:  Rob McEwen 
% DATE:    01/3/20
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
  if( exist('dataLblsa') ~= 1 ), 
    disp(' You must first create dataLblsa. It is not on the stack.');
    return
  end

  dataNav(:,nfix:heading_bias) = dataLblsa(1:length(dataNav),2:heading_bias_sa);