addpath '/u/ryjo/matlab/wcoast';

if ~exist('gry','var'); gry=[.7 .7 .7]; end

xtr=0;
if xtr
 load Wcoast_iso;
 idx = find(iso(:,depth)==-100); iso100(:,1)=iso(idx,lon); iso100(:,2)=iso(idx,lat); 
 load isobath_200_1000m.mat
 figure(1); clf; 
 p=plot(iso100(:,1),iso100(:,2),'k.'); set(p,'color',gry,'markersize',4); hold on;
 p=plot(iso200(:,1),iso200(:,2),'k.'); set(p,'color',gry,'markersize',4);
 p=plot(iso1000(:,1),iso1000(:,2),'k.'); set(p,'color',gry,'markersize',4);
 save /u/ryjo/matlab/wcoast/isos iso100 iso200 iso1000
 return
else
 load isos
 % p=plot(iso100(:,1),iso100(:,2),'k.'); set(p,'color',gry,'markersize',4);
 p=plot(iso200(:,1),iso200(:,2),'k.'); set(p,'color',gry,'markersize',4);
 p=plot(iso1000(:,1),iso1000(:,2),'k.'); set(p,'color',gry,'markersize',4);
end



% function plot_iso(isodepths,pltlim,colorstr);
% function plot_iso(col);isodepths,pltlim,colorstr);
% load /u/ryjo/matlab/Wcoast_iso
% for N = 1:length(isodepths);
%  idx = find(iso(:,depth)==-1*isodepths(N) &...
%  iso(:,lat)>=pltlim(3) & iso(:,lat)<=pltlim(4) &...
%  iso(:,lon)>=pltlim(1) & iso(:,lon)<=pltlim(2));
%  plot(iso(idx,lon),iso(idx,lat),colorstr);
% end

