%
%    HCTRL - script to plot heading control parameters in the current axes
%
%    MIT SeaGrant Lab
%
% Copyright (C) 1997-1998, Massachussetts Institute of Technology
% Sea Grant Underwater Vehicles Laboratory
% $Revision: 1.1 $, $Date: 2000/01/10 19:07:58 $
%
plot( dataDC(:,1), 180/pi*dataDC(:,psiProp), 'Color', 'r' );
line( dataDC(:,1), 180/pi*dataDC(:,psiInt),  'Color', [0 .75 .75] );
line( dataDC(:,1), 180/pi*dataDC(:,psiRate), 'Color', [0 .5 0] );
line( dataDC(:,1), 180/pi*dataDC(:,cDeltaR), 'Color', 'b' );
zoom on
grid on
title( ['PID Heading (prop r, deriv g, rudr b)'] );
legend( 'Prop.', 'Int.', 'Deriv', 'Cmd. Rudder');
xlabel( 'Elapsed Time Sec.' )
ylabel( 'Control Activity Deg.' )
