%
% PURPOSE: Return Date and Time string
% AUTHOR:  Rob McEwen
% DATE:    98/11/4
%
  function [dateStr] = myDate()
  tvec = clock;
  tstr = ...
  [' ',num2str(tvec(4)),':',num2str(tvec(5)),':',num2str(round(tvec(6)))];
  dateStr = [date,tstr];
  return

