%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: rb2gr.m,v 1.1 2000/01/10 19:08:27 rob Exp $	

function ep = rb2gr( r, b, sp )

if nargin < 3, sp = [0 0]; end

b = b*pi/180;
ep = sp + r*[cos(b) sin(b)];
