%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% PURPOSE: Set some basic units
% AUTHOR:  Initial; rsm
% DATE:    99/12/14
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Units Conversions:
%
  in2m = .0254;             % Inches to meters.
  d2r  = pi/180;            % Degrees to radians
  r2d  = 180/pi;            % Radians to degrees
  s2kg = 14.59390;          % Slugs to kg
  ft2m = .3048;             % Feet to meters
  sft2kgm2 = 1.355818;      % Slug-ft^2 to kg-m^2
  lbin2kgm2= 2.926397e-4;   % Pound-in^2 to kg-m^2
  lbf2n    = 4.448;         % Pounds force to Newtons
  kph2mps  = 1852/3600;     % Knots to meters per sec
  ftlbf2nm = 1.3558179;     % Foot-pounds torque to Newton-meters.
  oi2nm    = .0070615516;   % Ounce-inches to Newton-meters.
  nm2m     = 1852;          % Nautical miles to meters
  rpm2rps  = pi/30;         % Rev per minute to radians per second.
%
% Fundamental Constants:
%
  g        = 9.806;         % Free-fall acceleration due to gravity; m/sec^2.
  rE       = 6371000;       % Mean Earth radius, m.
  rEP      = 6356755;       % Polar Earth radius, m.
  rEE      = 6378140;       % Equitorial Earth radius, m.
  ecc      = .0818192;      % Eccentricity
  rho      = 1028;          % Density of sea water at 0 Deg C; kg/m^3
%
