%O2_INCL      Plots vehicle inclination sensors.

%   Plots the commanded and measured pitch angles in the top window and the
%   measured roll angle in the bottom window.  POS is an optional string
%   argument specifying the position of the window on the screen.
%
%   See also WINPOS.
%   B. A. Moran, 1995

%----------------------------------------------------------------------
%                      Copyright (C) 1994-1996
%               Massachussetts Institute of Technology
%              Sea Grant Underwater Vehicles Laboratory
%----------------------------------------------------------------------
%     $Revision: 1.1 $			$Date: 2000/01/10 19:08:16 $
%----------------------------------------------------------------------

global run_name;

clf
set( gcf, 'name', 'Odyssey II Vehicle Attitude' );

subplot( 3, 1, 1 )		% pitch
o2_pitch( data(:,m_present_time), data(:,c_pitch), data(:,m_pitch) );


subplot( 3, 1, 2 )		% pitch
o2_pcntl

subplot( 3, 1, 3 )		% roll
o2_roll( time, data(:,m_roll) );
