clear all

% cd ..
% missionN=['00';'01';'02';'03';'04';'05';'06';'09';'10'];
% missionN=['00';'04'];
% save missionN missionN;
% [N x] = size(missionN);

% for M = 1:N;
 % eval(['cd 2000.240.' missionN(M,:)]);
 % disp(['matlabing mission ' int2str(M)]);
 % clear missions;
 dataCTD; save dataCTD; clear all; 
 dataGPS; save dataGPS; clear all; 
 dataN; save dataN; clear all; 
 dataD; save dataD; clear all; 
 methane; save methane; clear all
 % cd ..;  load missionN;
% end