%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% PURPOSE: Plot AHRS data.
% AUTHOR:  Initial; rsm
% DATE:    00/1/10
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Units and Fundamental Constants:
  units
  hardflag=0;

  time = 1;

  str = [', Case:',run_name, ' ',myDate];
  PaperPosn = [.5 .5 3.75 2.5];
  FigurePosn = [5 30 815 760];
  i = 0;

  if exist( 'crsBwFig1' ) ~= 1
      crsBwFig1 = figure;
  else 
      figure( crsBwFig1 ); 
  end
    
  set( crsBwFig1, 'name', 'Attitude & Heading Reference', ...
       'DeleteFcn', 'clear crsBwFig1' );
  set(gcf,'position',position)
  clf

    subplot(3,1,1)
    [xx,yy]   = stairs( dataNav(:,time), dataNav(:,mPhi)/d2r);
    [xx1,yy1] = stairs( dataCB(:,time),  dataCB(:,mRollCB));
    plot(xx, yy, xx1, yy1);
    ylabel('Degrees')
    title(['Roll, Degrees',str]);
    grid on
    zoom on

    subplot(3,1,2)
    [xx,yy]   = stairs( dataNav(:,time), dataNav(:,mTheta)/d2r);
    [xx1,yy1] = stairs( dataCB(:,time),  dataCB(:,mPitchCB));
    plot(xx, yy, xx1, yy1);
    ylabel('Degrees')
    title(['Pitch, Degrees',str]);
    grid on
    zoom on

    subplot(3,1,3)
    [xx,yy]   = stairs( dataNav(:,time), mod360(dataNav(:,mPsi)/d2r));
    [xx1,yy1] = stairs( dataCB(:,time),  mod360(dataCB(:,mYawCB)));
    plot(xx, yy, xx1, yy1);
    ylabel('Degrees')
    title(['Yaw, Degrees',str]);
    grid on
    zoom on

    pause(.5)
  if exist( 'CrsBwFig2' ) ~= 1
      CrsBwFig2 = figure;
  else 
      CrsBwFig2 = figure( CrsBwFig2 ); 
  end
    
  set( CrsBwFig2, 'name', 'Body Rates', ...
       'DeleteFcn', 'clear CrsBwFig2' );
  set(gcf,'position',position)
  clf
    subplot(3,1,1)
    [xx,yy]   = stairs( dataNav(:,time), dataNav(:,mOmega_x)/d2r);
    [xx1,yy1] = stairs( dataCB(:,time),  dataCB(:,mOmega_xCB));
    plot(xx, yy, xx1, yy1);
    ylabel('Degrees/Second')
    title(['X Axis Body Rate (Omega B x), Degrees/Sec',str]);
    grid on
    zoom on

    subplot(3,1,2)
    [xx,yy] = stairs( dataNav(:,time), dataNav(:,mOmega_y)/d2r);
    [xx1,yy1] = stairs( dataCB(:,time),  dataCB(:,mOmega_yCB));
    plot(xx, yy, xx1, yy1);
    ylabel('Degrees/Second')
    title(['Y Axis Body Rate (Omega B y), Degrees/Sec',str]);
    grid on
    zoom on

    subplot(3,1,3)
    [xx,yy] = stairs( dataNav(:,time), dataNav(:,mOmega_z)/d2r);
    [xx1,yy1] = stairs( dataCB(:,time),  dataCB(:,mOmega_zCB));
    plot(xx, yy, xx1, yy1);
    ylabel('Degrees/Second')
    title(['Z Axis Body Rate (Omega B z), Degrees/Sec',str]);
    grid on
    zoom on



    pause(.5)
  if exist( 'CrsBwFig3' ) ~= 1
      CrsBwFig3 = figure;
  else 
      CrsBwFig3 = figure( CrsBwFig3 ); 
  end
    
  set( CrsBwFig3, 'name', 'Acceleration', ...
       'DeleteFcn', 'clear CrsBwFig3' );
  set(gcf,'position',position)
  clf
    subplot(3,1,1)
    [xx,yy] = stairs( dataCB(:,time),  dataCB(:,mAccel_xCB));
    plot(xx, yy);
    ylabel('Meters/Second')
    title(['Acceleration of Vehicle CM Resolved onto Body X, Meters/Sec^2',str]);
    grid on
    zoom on


    subplot(3,1,2)
    [xx,yy] = stairs( dataCB(:,time),  dataCB(:,mAccel_yCB));
    plot(xx, yy);
    ylabel('Meters/Second')
    title(['Acceleration of Vehicle CM Resolved onto Body Y, Meters/Sec^2',str]);
    grid on
    zoom on


    subplot(3,1,3)
    [xx,yy] = stairs( dataCB(:,time),  dataCB(:,mAccel_zCB));
    plot(xx, yy);
    ylabel('Meters/Second')
    title(['Acceleration of Vehicle CM Resolved onto Body Z, Meters/Sec^2',str]);
    grid on
    zoom on


    pause(.5)
  if exist( 'CrsBwFig4' ) ~= 1
      CrsBwFig4 = figure;
  else 
      CrsBwFig4 = figure( CrsBwFig4 ); 
  end
    
  set( CrsBwFig4, 'name', 'DorOdyssey Body Rates', ...
       'DeleteFcn', 'clear CrsBwFig4' );
  set(gcf,'position',position)
  clf
    subplot(3,1,1)
    [xx,yy] = stairs( dataCB(:,time),  dataCB(:,mMag_xCB));
    plot(xx, yy);
    ylabel('Gauss(?)')
    title(['Magnetic Field Resolved onto Body X',str]);
    grid on
    zoom on


    subplot(3,1,2)
    [xx,yy] = stairs( dataCB(:,time),  dataCB(:,mMag_yCB));
    plot(xx, yy);
    ylabel('Gauss(?)')
    title(['Magnetic Field Resolved onto Body Y',str]);
    grid on
    zoom on


    subplot(3,1,3)
    [xx,yy] = stairs( dataCB(:,time),  dataCB(:,mMag_zCB));
    plot(xx, yy);
    ylabel('Gauss(?)')
    title(['Magnetic Field Resolved onto Body Z',str]);
    grid on
    zoom on

  return






  i = i+1;
  figure(i)
  if hardflag ==3, set(gcf,'PaperPosition',PaperPosn), end
  set(gcf,'position',position)
  clf
  subplot(3,1,1)
  plot(dataNav(:,tIx), dataNav(:,[pitchIx])/d2r);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Degrees')
  title(['Pitch, Degrees',str]);
  grid on
  subplot(3,1,2)
  plot(dataNav(:,tIx), [dataNav(:,qIx)]/d2r);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Deg/Sec')
  title(['Body Rotational Rate q (Omega_N_B_y)',str]);
  xlabel('Seconds');
  grid on
  subplot(3,1,3)
  plot(dataNav(:,tIx), [dataNav(:,deltaEIx)]*180/pi);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Degrees')
  title(['Elevator Angle',str]);
  xlabel('Seconds');
  grid on

  i = i+1;
  figure(i)
  if hardflag ==3, set(gcf,'PaperPosition',PaperPosn), end
  set(gcf,'position',position)
  clf
  subplot(3,1,1)
  plot(dataNav(:,tIx), dataNav(:,[yawIx])/d2r);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Degrees')
  title(['Heading, Degrees',str]);
  grid on
  subplot(3,1,2)
  plot(dataNav(:,tIx), dataNav(:,[rIx])/d2r);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Deg/Sec')
  title(['Body Rotational Rate r (Omega_N_B_z)',str]);
  grid on
  subplot(3,1,3)
  plot(dataNav(:,tIx), [dataNav(:,deltaRIx)]*180/pi);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Degrees')
  title(['Rudder Angle',str]);
  xlabel('Seconds');
  grid on

  i = i+1;
  figure(i)
  if hardflag ==3, set(gcf,'PaperPosition',PaperPosn), end
  set(gcf,'position',position)
  clf
  subplot(2,1,1)
  plot(dataNav(:,tIx), dataNav(:,[rollIx])/d2r);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Degrees')
  title(['Roll, Degrees',str]);
  grid on
  subplot(2,1,2)
  plot(dataNav(:,tIx), dataNav(:,[pIx])/d2r);
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('Deg/Sec')
  title(['Body Rotational Rate p (Omega_N_B_x)',str]);
  grid on

  i = i+1;
  figure(i)
  if hardflag ==3, set(gcf,'PaperPosition',PaperPosn), end
  set(gcf,'position',position)
  clf
  plot(dataNav(:,yPosIx), dataNav(:,[xPosIx]));
  if hardflag == 3, set(gca,'FontUnits','Normalized'), end
  ylabel('North, Meters')
  xlabel('East, Meters')
  title(['Vehicle Location in Earth Fixed Coordinates',str]);
  grid on

