%    DOCK - Script to add the data cloud of the estimated position of the
%    AOSN docking station (M_DOCK_N, M_DOCK_E) to the current axes.
%
%    B. A. Moran, 02-Jan-1998

%    Copyright (C) 1998, Massachussetts Institute of Technology
%    Sea Grant Autonomous Underwater Vehicles Laboratory
%    $Id: dock.m,v 1.1 2000/01/10 19:07:52 rob Exp $	


ind = find( data(:,m_cnav_status) > 0 );

plot( data(ind,m_present_time), data(ind,m_depth) - data(ind,m_cnav_axial), ...
    'd' );

ind = find( data(:,m_cnav_status) == 0 );
line( data(ind,m_present_time), data(ind,m_depth) - data(ind,m_cnav_axial), ...
    'Marker', '*', 'LineStyle', 'none' );

set( gca, 'YDir', 'rev' );

title( ['Estimated Dock Depth: ' run_name] );
xlabel( 'elapsed time (s)' );
ylabel( 'depth (m)' );

zoom on
