%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% PURPOSE: Plot raw CTD data
% AUTHOR:  Initial; rsm
% DATE:    99/12/14
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Units and Fundamental Constants:
  units

  str = [', Case:',run_name, ' ',myDate];
  PaperPosn = [.5 .5 3.75 2.5];
  FigurePosn = [5 30 815 760];
  i = 0;

  if exist( 'ctdFig' ) ~= 1
      ctdFig = figure;
  else 
      figure( ctdFig ); 
  end
    
  set( ctdFig, 'name', 'DorOdyssey CTD', ...
       'DeleteFcn', 'clear ctdFig' );
  set(gcf,'position',position)
  clf

    subplot(3,1,1)
    [xx,yy] = stairs( ctdlog(:,1), ctdlog(:,conductivity));
    plot(xx,yy);
    ylabel('S/m')
    title(['Conductivity',str]);
    grid on

    subplot(3,1,2)
    [xx,yy] = stairs( ctdlog(:,1), ctdlog(:,temperature));
    plot(xx,yy);
    ylabel('Degrees Celsius')
    title(['Temperature',str]);
    grid on

    subplot(3,1,3)
    [xx,yy] = stairs( dataNav(:,1), dataNav(:,mDepth));
    plot(xx,yy);
    set( gca, 'ydir', 'reverse' );
    ylabel('Meters')
    title(['Depth',str]);
    grid on


