%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: o2_power.m,v 1.1 2000/01/10 19:08:18 rob Exp $	

subplot( 4, 1, 1 )
cla
plot( data(:,m_present_time), data(:,m_km_voltage), 'ro' );
title( ['Keithley Metrabytes: ' run_name ] );
ylabel( 'voltage (V)' )
zoom on

subplot( 4, 1, 2 )
cla
plot( data(:,m_present_time), data(:,m_km_current), 'color', [0 .7 0], ...
    'marker', 'o' );
ylabel( 'current (A)' )
zoom on

subplot( 2, 1, 2 )
cla
plot( data(:,m_present_time), ...
    data(:,m_km_current).*data(:,m_km_voltage), 'o' );
ylabel( 'power (W)' )
xlabel( 'mission time (s)' )
zoom on
