%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: setpoint.m,v 1.1 2000/01/10 19:08:33 rob Exp $	

function setpoint( time, hdg, spd, r0 )

dist = spd * time;

if nargin < 4, r0 = [0 0]; end
