% SALSP  Salinity and sound speed.
%    [SAL,SPD] = SALSP( cond(s/m), temp(deg C), pressure(dbar) )

%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: salsp.m,v 1.1 2000/01/10 19:08:32 rob Exp $	

function [sal,spd] = salsp( c, t, p )

sal = sw_salt( 10*c/sw_c3515, t, p );

if nargout > 1
    spd = sw_svel( sal, t, p );
end
