%    O2_THSPD - function to plot propeller speed
%
%       o2_thspd( time, propspd )
%
%    B. A. Moran

%    Copyright (C) 1997-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: o2_thspd.m,v 1.1 2000/01/10 19:08:21 rob Exp $

function o2_thspd( time, propspd )

plot( time, propspd );
title( 'Measured Propeller' );
ylabel( 'propeller speed (rpm)' );
xlabel( 'elapsed time (s)' );

zoom on
