%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: adv.m,v 1.1 2000/01/10 19:07:44 rob Exp $	

ind = find(finite(data(:,adv_samp)));

subplot( 3, 1, 1 )
plot( time(ind), data(ind,[adv_vx adv_vy adv_vz]) )
title( ['ADV Channels x(b), y(g), z(r): ' run_name] )
ylabel( 'vel (m/s)' )

subplot( 3, 1, 2 )
plot( time(ind), data(ind,[adv_a1 adv_a2 adv_a3]) )
ylabel( 'amp (dB)' )

subplot( 3, 1, 3 )
plot( time(ind), 100*data(ind,[adv_c1 adv_c2 adv_c3]) )
ylabel( 'corr (%)' )
xlabel( 'elapsed time (s)' )
