function wclandfill(AX,fillcolor);

load wcmask.mat
idx=find(LON>=AX(1)&LON<=AX(2) & LAT>=AX(3)&LAT<=AX(4));
lon=LON(idx); lat=LAT(idx);
%% add remaining points
closelat = [AX([3 3 4 4])]';
closelon = [lon(length(lon)) AX([2 2]) lon(1)]';
fillLon=[lon;closelon]; fillLat=[lat;closelat];
fill(fillLon,fillLat,fillcolor); hold on;
load wc; plot(wclon,wclat,'k');
axis(AX);

