%% temp_cal.m : get calibration coefficients for SeaBird Temperature sensors
%% input is temperature sensor serial number 

function [t_a, t_b, t_c, t_d, t_f0] = temp_cal(tempserial);

if tempserial==4123;
 disp('   Temperature sensor SN 4123');
 %% IPTS-68 coefficients
 t_a = 3.67988003e-03;
 t_b = 6.03911684e-04;
 t_c = 1.63056430e-05;
 t_d = 2.12888340e-06;
 t_f0 = 3171.158;

elseif tempserial==4122;
 disp('   Temperature sensor SN 4122');
 %% IPTS-68 coefficients
 t_a = 3.67988033e-03;
 t_b = 6.06596377e-04;
 t_c = 1.66383558e-05;
 t_d = 2.13805613e-06;
 t_f0 = 3188.468;

elseif tempserial==2813;
 disp('   Temperature sensor SN 2813');
 %% IPTS-68 coefficients
 t_a = 3.67999722e-03;
 t_b = 6.02624547e-04;
 t_c = 1.59294960e-05;
 t_d = 2.06238399e-06;
 t_f0 = 2798.583;
  
elseif tempserial==2819;
 disp('   Temperature sensor SN 2819');
 %% IPTS-68 coefficients
 t_a = 3.67997127e-03;
 t_b = 6.01240767e-04;
 t_c = 1.58748231e-05;
 t_d = 2.03516651e-06;
 t_f0 = 3039.622;

else
 disp(['Error: Unknown Temperature Sensor Serial Number']); return
end
