str1=(['AUV Survey of 2000.238 (25 August 2000)']); disp(str1);
str2=(['Upwelling source region (Davenport/Santa Cruz)']); disp(str2);

YYYY=2000; DDD=238; 
%% consecutive successful mission numbers, for concatenation into survey
mn=[1 3:12];	

%% Construct mission list for survey
for N=1:length(mn);
 if mn(N)<10; nt=['0' int2str(mn(N))]; else; nt=[int2str(mn(N))]; end 
 missionlist(N,:)=[int2str(YYYY) '.' int2str(DDD) '.' nt];
end

surveyfilename=['auv_' int2str(YYYY) int2str(DDD) '_day']; 
