function pH = calc_pH(Vo, slp, off, tmp);
%% to calculate pH give sbe voltage, water temperature, and slope/offset from phfit.exe

fc = 1.98416e-04;
pH = 7 + ((Vo - off) ./ (slp * (273.15 + tmp) * fc));
