%% cond_cal.m : get calibration coefficients for SeaBird Conductivity sensors
%% input is conductivity sensor serial number 

function [c_a, c_b, c_c, c_d, c_m, CPcor] = cond_cal(condserial);

if condserial==2478;
 disp('   Conductivity sensor SN 2478');
 %% ABCDM coefficients
 c_a = 1.55948296e-03;
 c_b = 1.51788405;
 c_c = -10.4754563;
 c_d = -8.45139917e-05;
 c_m = 2.9;
 CPcor = -9.57e-08;

elseif condserial==2514;
 disp('   Conductivity sensor SN 2514');
 %% ABCDM coefficients
 c_a = 1.13996214e-04;
 c_b = 1.61186242;
 c_c = -10.6381051;
 c_d = -8.83995606e-05;
 c_m = 3.9;
 CPcor = -9.57e-08;

elseif condserial==2258;
 disp('   Conductivity sensor SN 2258');
 %% ABCDM coefficients
 c_a = 2.85475358e-22;
 c_b = 1.56709467;
 c_c = -10.6453205;
 c_d = -1.09885720e-05;
 c_m = 23.7;
 CPcor = -9.57e-08;
  
elseif condserial==2405;
 disp('   Conductivity sensor SN 2405');
 %% ABCDM coefficients
 c_a = 2.80551784e-04;
 c_b = 1.59349759;
 c_c = -10.9374861;
 c_d = -8.48450433e-05;
 c_m = 3.5;
 CPcor = -9.57e-08;

else
 disp(['Error: Unknown Conductivity Sensor Serial Number']); return
end
