%O2_PITCH    Comprehensive plots of pitch and pitch control
%
%   B. A. Moran, 1995-1997

%    Copyright (C) 1995-1998
%    Massachussetts Institute of Technology
%    Sea Grant AUV Laboratory
%    $Id: o2_pitch.m,v 1.1 2000/01/10 19:08:17 rob Exp $	

set( gcf, 'name', 'Odyssey II Pitch Control' );

subplot( 2, 1, 1 )
cla
[xx,yy] = stairs( time, data(:,c_pitch)*180/pi );
plot( time, data(:,m_pitch)*180/pi, xx, yy );

title( ['Commanded and Measured Pitch:  ' run_name] );
xlabel( 'elapsed time (s)' );
ylabel( 'pitch (deg)' );
zoom on

subplot( 2, 1, 2 )
cla
pctrl
