%    LBLADVNC - 
%
%    B. A. Moran, 11-Sep-1998

%    Copyright (C) 1995-1998, Massachussetts Institute of Technology
%    Sea Grant Autonomous Underwater Vehicles Laboratory
%    $Id: lbladvnc.m,v 1.1 2000/01/10 19:08:02 rob Exp $	

ind1 = find( data(:,m_lbl_ping_time) >= 0 );
ind2 = find( finite(data(:,lbl_newdata)) );

advance = NaN*zeros(size(data,1),2);

advance(ind2,:) = data(ind2,[m_dr_north m_dr_east]) - ...
    data(ind1,[m_dr_north m_dr_east]);
        
