survey_assembly_setup;
for N=1:length(missionlist)
 eval(['cd ' missionlist(N,:)]);
 missiondata; disp([missionID]);
 auvstarts(N,:)=ep([3 1]);
 auvends(N,:)=ep([4 2]);
 cd ..
end

figure(1); clf; bigfig
AX=[-122.5 -121.75 36.5 37.05]; gry=[.7 .7 .7];
wclandfill(AX,gry); plot_iso;
plot(auvstarts(:,1),auvstarts(:,2),'g*'); 
plot(auvends(:,1),auvends(:,2),'r*'); 
